=================
django-propaganda
=================

Hey you, political leader, founder of a new religion or spiritual guru! With
this application, your acolytes will receive the official organizational
propaganda pamphlets right into their inboxes. Keep them updated with the Truth!

This simple Django application is made to be used for trivial newsletter
(**pamphlets**) deliveries with your information (**propaganda**), where you
supply the raw content (both plain text and HTML versions) to be delivered.
Subscribers (**subscribers**) will then receive the emails you send.

Documentation
=============

Read the latest documentation on the fine `Read the docs`_ project for
installation, configuration and customization instructions, and also to read
examples and tutorials about how to use the package in different scenarios.

.. _`Read the docs`: http://readthedocs.org/docs/django-propaganda/en/latest/
